import { getCanvasSessionKey } from "./utils.js";
function isSessionObject(obj) {
    return (typeof obj === "object" &&
        typeof obj.app === "string" &&
        typeof obj.sessionPrivateKey === "string" &&
        typeof obj.expiration === "number");
}
export function getSessionObject(chain, signerAddress) {
    const sessionKey = getCanvasSessionKey(chain, signerAddress);
    const item = localStorage.getItem(sessionKey);
    if (item === null) {
        return null;
    }
    let sessionObject;
    try {
        sessionObject = JSON.parse(item);
    }
    catch (err) {
        localStorage.removeItem(sessionKey);
        return null;
    }
    if (!isSessionObject(sessionObject)) {
        localStorage.removeItem(sessionKey);
        return null;
    }
    return sessionObject;
}
export function setSessionObject(chain, signerAddress, sessionObject) {
    const sessionKey = getCanvasSessionKey(chain, signerAddress);
    localStorage.setItem(sessionKey, JSON.stringify(sessionObject));
}
export function removeSessionObject(chain, signerAddress) {
    const sessionKey = getCanvasSessionKey(chain, signerAddress);
    localStorage.removeItem(sessionKey);
}
